==> flink-ml-2.1.0-src.tgz: flink-ml-2.1.0/docs/content/_index.md <==
---
title: Apache Flink Machine Learning Library
type: docs
bookToc: false
---
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# Flink ML: Apache Flink Machine Learning Library

Flink ML is a library which provides machine learning (ML) APIs and
infrastructures that simplify the building of ML pipelines. Users can implement
ML algorithms with the standard ML APIs and further use these infrastructures to
build ML pipelines for both training and inference jobs.

{{< columns >}}
## Try Flink ML

If you’re interested in playing around with Flink ML, check out our [quick
start]({{< ref "docs/try-flink-ml/quick-start" >}}). It provides a simple
example to submit and execute a Flink ML job on a Flink cluster.

<--->

## Get Help with Flink ML

If you get stuck, check out our [community support
resources](https://flink.apache.org/community.html). In particular, Apache
Flink’s user mailing list is consistently ranked as one of the most active of
any Apache project, and is a great way to get help quickly.

{{< /columns >}}

Flink ML is developed under the umbrella of [Apache
Flink](https://flink.apache.org/).

==> flink-ml-2.2.0-src.tgz: flink-ml-2.2.0/docs/content/_index.md <==
---
title: Apache Flink Machine Learning Library
type: docs
bookToc: false
---
<!--
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
-->

# Flink ML: Apache Flink Machine Learning Library

Flink ML is a library which provides machine learning (ML) APIs and
infrastructures that simplify the building of ML pipelines. Users can implement
ML algorithms with the standard ML APIs and further use these infrastructures to
build ML pipelines for both training and inference jobs.

{{< columns >}}
## Try Flink ML

If you’re interested in playing around with Flink ML, check out our [quick
start]({{< ref "docs/try-flink-ml/java/quick-start" >}}). It provides a simple
example to submit and execute a Flink ML job on a Flink cluster.

<--->

## Get Help with Flink ML

If you get stuck, check out our [community support
resources](https://flink.apache.org/community.html). In particular, Apache
Flink’s user mailing list is consistently ranked as one of the most active of
any Apache project, and is a great way to get help quickly.

{{< /columns >}}

Flink ML is developed under the umbrella of [Apache
Flink](https://flink.apache.org/).
